PyR3.factory package
====================

Subpackages
-----------

.. toctree::
   :maxdepth: 4

   PyR3.factory.fields

Submodules
----------

PyR3.factory.MeshFactory module
-------------------------------

.. automodule:: PyR3.factory.MeshFactory
   :members:
   :undoc-members:
   :show-inheritance:

Module contents
---------------

.. automodule:: PyR3.factory
   :members:
   :undoc-members:
   :show-inheritance:
